==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Doc/Doxygen/Python-API/Source/CDPL/Biomol/ResidueType.doc.py <==
#
# This file is part of the Chemical Data Processing Toolkit
#
# Copyright (C) Thomas Seidel <thomas.seidel@univie.ac.at>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; see the file COPYING. If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

##
# \brief 
#
class ResidueType(Boost.Python.instance):

    ##
    # \brief 
    #
    UNKNOWN = 0

    ##
    # \brief 
    #
    OTHER = 1

    ##
    # \brief 
    #
    NON_POLYMER = 2

    ##
    # \brief 
    #
    PEPTIDE_CARBOXY_TERMINUS = 3

    ##
    # \brief 
    #
    PEPTIDE_AMINO_TERMINUS = 4

    ##
    # \brief 
    #
    PEPTIDE_LINKING = 5

    ##
    # \brief 
    #
    BETA_PEPTIDE_LINKING = 6

    ##
    # \brief 
    #
    GAMMA_PEPTIDE_LINKING = 7

    ##
    # \brief 
    #
    PEPTIDE_LIKE = 8

    ##
    # \brief 
    #
    RNA_HYDROXY_TERMINUS = 9

    ##
    # \brief 
    #
    DNA_HYDROXY_TERMINUS = 10

    ##
    # \brief 
    #
    RNA_LINKING = 11

    ##
    # \brief 
    #
    DNA_LINKING = 12

    ##
    # \brief 
    #
    SACCHARIDE_LINKING = 13

    ##
    # \brief 
    #
    SACCHARIDE = 14

==> CDPKit-1.2.0.dev1.tar.gz: CDPKit-1.2.0.dev1/Doc/Doxygen/Python-API/Source/CDPL/Biomol/ResidueType.doc.py <==
#
# This file is part of the Chemical Data Processing Toolkit
#
# Copyright (C) Thomas Seidel <thomas.seidel@univie.ac.at>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; see the file COPYING. If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

##
# \brief 
#
class ResidueType(Boost.Python.instance):

    ##
    # \brief 
    #
    UNKNOWN = 0

    ##
    # \brief 
    #
    OTHER = 1

    ##
    # \brief 
    #
    NON_POLYMER = 2

    ##
    # \brief 
    #
    L_PEPTIDE_CARBOXY_TERMINUS = 3

    ##
    # \brief 
    #
    L_PEPTIDE_AMINO_TERMINUS = 4

    ##
    # \brief 
    #
    D_PEPTIDE_AMINO_TERMINUS = 5

    ##
    # \brief 
    #
    PEPTIDE_LINKING = 6

    ##
    # \brief 
    #
    L_PEPTIDE_LINKING = 7

    ##
    # \brief 
    #
    D_PEPTIDE_LINKING = 8

    ##
    # \brief 
    #
    L_BETA_PEPTIDE_LINKING = 9

    ##
    # \brief 
    #
    D_BETA_PEPTIDE_LINKING = 10

    ##
    # \brief 
    #
    L_GAMMA_PEPTIDE_LINKING = 11

    ##
    # \brief 
    #
    D_GAMMA_PEPTIDE_LINKING = 12

    ##
    # \brief 
    #
    PEPTIDE_LIKE = 13

    ##
    # \brief 
    #
    RNA_3_HYDROXY_TERMINUS = 14

    ##
    # \brief 
    #
    RNA_5_HYDROXY_TERMINUS = 15

    ##
    # \brief 
    #
    DNA_3_HYDROXY_TERMINUS = 16

    ##
    # \brief 
    #
    DNA_5_HYDROXY_TERMINUS = 17

    ##
    # \brief 
    #
    RNA_LINKING = 18

    ##
    # \brief 
    #
    DNA_LINKING = 19

    ##
    # \brief 
    #
    L_RNA_LINKING = 20

    ##
    # \brief 
    #
    L_DNA_LINKING = 21

    ##
    # \brief 
    #
    L_SACCHARIDE_1_4_LINKING = 22

    ##
    # \brief 
    #
    D_SACCHARIDE_1_4_LINKING = 23

    ##
    # \brief 
    #
    L_SACCHARIDE_ALPHA_LINKING = 24

    ##
    # \brief 
    #
    D_SACCHARIDE_ALPHA_LINKING = 25

    ##
    # \brief 
    #
    L_SACCHARIDE_BETA_LINKING = 26

    ##
    # \brief 
    #
    D_SACCHARIDE_BETA_LINKING = 27

    ##
    # \brief 
    #
    L_SACCHARIDE = 28

    ##
    # \brief 
    #
    D_SACCHARIDE = 29

    ##
    # \brief 
    #
    SACCHARIDE = 30
